package
Version:
v0.1.32
Opens a new window with list of versions in this module.
Published: Jul 22, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 18
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package update securely replaces a release-built Aegis executable.
type Result struct {
CurrentVersion string `json:"current_version"`
LatestVersion string `json:"latest_version"`
UpdateAvailable bool `json:"update_available"`
Updated bool `json:"updated"`
Executable string `json:"executable,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.